@@ -15,8 +15,10 @@ utils::globalVariables(
     "Element",
     "export",
     "feedtype",
+    "fill_value",
     "final_value_processed",
     "from_code",
+    "groups",
     "import",
     "Imp/Exp",
     "Info_Format",
@@ -42,6 +44,7 @@ utils::globalVariables(
     "loss_share",
     "Name",
     "No",
+    "prefilled",
     "proc",
     "process",
     "proc_cbs_code",
@@ -49,10 +52,12 @@ utils::globalVariables(
     "prod_ygpit_mg",
     "product_fraction",
     "product_residue",
+    "proxy_ratio",
     "SACO_link",
     "scaling",
     "seed",
     "sex",
+    "source_value",
     "stock_variation",
     "supply",
     "Timeline_End",
@@ -67,6 +72,9 @@ utils::globalVariables(
     "unit",
     "value",
     "Value",
+    "value_carried_backward",
+    "value_carried_forward",
+    "value_interpfilled",
     "value_proc",
     "value_proc_raw",
     "value_to_process",
