@@ -15,8 +15,15 @@ test_that("trade source data is expanded from year range to single year rows", {
     Name = c("a_1", "a_2", "a_3", "b", "b", "b", "b", "c_2", "c_4"),
     Trade = c("t1", "t1", "t1", "t2", "t2", "t2", "t2", "t3", "t3"),
     Info_Format = c(
-      "year", "year", "year", "partial_series", "partial_series",
-      "partial_series", "partial_series", "year", "year"
+      "year",
+      "year",
+      "year",
+      "partial_series",
+      "partial_series",
+      "partial_series",
+      "partial_series",
+      "year",
+      "year"
     ),
     Year = c(1, 2, 3, 1, 2, 3, 4, 2, 4),
   )
